// server.js (Node.js example using Express)
const express = require('express');
const fetch = require('node-fetch');
const app = express();
const port = 3000;

// Store API key in an environment variable (or a secure config)
const API_KEY = process.env.OPENAI_API_KEY;
const MODEL = 'gpt-3.5-turbo';

app.use(express.json());

app.post('/chat', async (req, res) => {
  try {
    const conversationHistory = req.body.conversationHistory;
    
    const response = await fetch('https://api.openai.com/v1/chat/completions', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
        'Authorization': `Bearer ${API_KEY}`,
      },
      body: JSON.stringify({
        model: MODEL,
        messages: conversationHistory,
        temperature: 0.7,
        max_tokens: 1000,
      }),
    });

    const data = await response.json();

    if (data.error) {
      return res.status(500).json({ error: data.error.message });
    }

    res.json(data.choices[0].message);
  } catch (error) {
    console.error('API Error:', error);
    res.status(500).json({ error: 'Failed to connect to API.' });
  }
});

app.listen(port, () => {
  console.log(`Server running at http://localhost:${port}`);
});
