// Configuration
const API_KEY = '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'; // 🔑 Replace this with your API key!
const MODEL = 'gpt-3.5-turbo';
const chatBox = document.getElementById('chatBox');
const userInput = document.getElementById('userInput');

// Store conversation history
let conversationHistory = [];

// Initialize with welcome message
document.addEventListener('DOMContentLoaded', () => {
  addMessage('Hello! How can I help you today?', 'bot');
});

async function sendMessage() {
  const message = userInput.value.trim();
  if (!message) return;
  
  // Add user's message to chat and history
  addMessage(message, 'user');
  conversationHistory.push({ role: 'user', content: message });
  userInput.value = ''; // Clear input
  
  // Add loading indicator with typing animation
  const loadingDiv = addMessage('', 'bot');
  const loadingText = document.createElement('div');
  loadingText.className = 'typing-indicator';
  loadingText.innerHTML = '<span></span><span></span><span></span>';
  loadingDiv.appendChild(loadingText);
  
  try {
    // Call OpenAI API
    const response = await fetch('https://api.openai.com/v1/chat/completions', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
        'Authorization': `Bearer ${API_KEY}`
      },
      body: JSON.stringify({
        model: MODEL,
        messages: conversationHistory,
        temperature: 0.7,
        max_tokens: 1000
      })
    });
    
    const data = await response.json();
    
    if (data.error) {
      chatBox.removeChild(loadingDiv);
      addMessage(`Error: ${data.error.message}`, 'bot error');
      return;
    }
    
    const botResponse = data.choices[0].message.content;
    
    // Save bot response to history
    conversationHistory.push({ role: 'assistant', content: botResponse });
    
    // Remove loading indicator and add real response
    chatBox.removeChild(loadingDiv);
    addMessage(botResponse, 'bot');
  } catch (error) {
    console.error('API Error:', error);
    chatBox.removeChild(loadingDiv);
    addMessage('Error: Failed to get response. Please check your API key and connection.', 'bot error');
  }
}

function addMessage(text, sender) {
  const messageDiv = document.createElement('div');
  messageDiv.className = `message ${sender}-message`;
  
  if (sender === 'bot' && text.includes('```')) {
    // Handle code blocks with syntax highlighting
    const parts = text.split(/```([a-zA-Z]*)\n|```/g);
    for (let i = 0; i < parts.length; i++) {
      if (i % 3 === 0) {
        // Regular text
        if (parts[i].trim()) {
          const textNode = document.createElement('div');
          textNode.className = 'text-content';
          textNode.innerHTML = formatText(parts[i]);
          messageDiv.appendChild(textNode);
        }
      } else if (i % 3 === 1) {
        // Language identifier (if any)
        const language = parts[i] || 'plaintext';
        i++;
        if (i < parts.length) {
          const codeBlock = document.createElement('div');
          codeBlock.className = 'code-block';
          
          const langLabel = document.createElement('div');
          langLabel.className = 'code-language';
          langLabel.textContent = language || 'code';
          
          const copyButton = document.createElement('button');
          copyButton.className = 'copy-button';
          copyButton.textContent = 'Copy';
          copyButton.onclick = function() {
            navigator.clipboard.writeText(parts[i]);
            copyButton.textContent = 'Copied!';
            setTimeout(() => {
              copyButton.textContent = 'Copy';
            }, 2000);
          };
          
          const codeHeader = document.createElement('div');
          codeHeader.className = 'code-header';
          codeHeader.appendChild(langLabel);
          codeHeader.appendChild(copyButton);
          
          const code = document.createElement('pre');
          code.textContent = parts[i];
          
          codeBlock.appendChild(codeHeader);
          codeBlock.appendChild(code);
          messageDiv.appendChild(codeBlock);
        }
      }
    }
  } else {
    // Regular text message
    messageDiv.innerHTML = formatText(text);
  }
  
  chatBox.appendChild(messageDiv);
  chatBox.scrollTop = chatBox.scrollHeight; // Auto-scroll
  return messageDiv;
}

function formatText(text) {
  // Convert URLs to clickable links
  text = text.replace(/(https?:\/\/[^\s]+)/g, '<a href="$1" target="_blank">$1</a>');
  
  // Convert markdown-style formatting
  text = text.replace(/\*\*(.*?)\*\*/g, '<strong>$1</strong>'); // Bold
  text = text.replace(/\*(.*?)\*/g, '<em>$1</em>'); // Italic
  
  // Convert line breaks to <br>
  text = text.replace(/\n/g, '<br>');
  
  return text;
}

// Handle Enter key and disable submit when empty
userInput.addEventListener('keypress', (event) => {
  if (event.key === 'Enter') {
    event.preventDefault();
    if (userInput.value.trim()) {
      sendMessage();
    }
  }
});

// Add clear chat button function
function clearChat() {
  // Keep only the welcome message
  while (chatBox.childNodes.length > 1) {
    chatBox.removeChild(chatBox.lastChild);
  }
  conversationHistory = [];
  addMessage('Chat cleared. How can I help you?', 'bot');
}

// Add API key update function
function updateAPIKey() {
  const newKey = prompt("Enter your OpenAI API Key:", API_KEY);
  if (newKey && newKey.trim() !== "") {
    localStorage.setItem("openai_api_key", newKey);
    location.reload();
  }
}

// Add theme toggle function
function toggleDarkMode() {
  document.body.classList.toggle('dark-mode');
  localStorage.setItem('darkMode', document.body.classList.contains('dark-mode'));
}

// Initialize dark mode based on preference
if (localStorage.getItem('darkMode') === 'true') {
  document.body.classList.add('dark-mode');
}