const express = require("express");
const fs = require("fs");
const path = require("path");
const axios = require("axios");

const app = express();
const PORT = process.env.PORT || 3000;

// File to store view count
const VIEW_COUNT_FILE = path.join(__dirname, "views.json");

// DexScreener API Endpoint (Updated)
const DEXSCREENER_API = "https://api.dexscreener.com/token-profiles/latest/v1";

// Serve static files (HTML, CSS, JS)
app.use(express.static(path.join(__dirname, "public")));

// Fetch memecoin data from DexScreener API (Updated)
app.get("/api/coins", async (req, res) => {
    try {
        const response = await axios.get(DEXSCREENER_API);
        res.json(response.data);
    } catch (error) {
        console.error("Error fetching data:", error);
        res.status(500).json({ error: "Failed to fetch coin data" });
    }
});

// Handle view count
app.get("/api/views", (req, res) => {
    let views = 0;
    if (fs.existsSync(VIEW_COUNT_FILE)) {
        const data = JSON.parse(fs.readFileSync(VIEW_COUNT_FILE, "utf-8"));
        views = data.views || 0;
    }
    res.json({ views });
});

// Update view count
app.post("/api/views", (req, res) => {
    let views = 0;
    if (fs.existsSync(VIEW_COUNT_FILE)) {
        const data = JSON.parse(fs.readFileSync(VIEW_COUNT_FILE, "utf-8"));
        views = data.views || 0;
    }
    views += 1;
    fs.writeFileSync(VIEW_COUNT_FILE, JSON.stringify({ views }), "utf-8");
    res.json({ views });
});

// Start the server
app.listen(PORT, () => {
    console.log(`Server is running on http://localhost:${PORT}`);
});
